//[mahjong-utils](../../../index.md)/[mahjongutils.yaku](../index.md)/[Yakus](index.md)/[ChurenNineWaiting](-churen-nine-waiting.md)

# ChurenNineWaiting

[common]\
val [ChurenNineWaiting](-churen-nine-waiting.md): [Yaku](../-yaku/index.md)

纯正九莲宝灯（九莲宝灯九面）
